Scriptname MeatFarmScheduler extends Quest  

;Properties
GlobalVariable property GameHour auto
GlobalVariable property GameDaysPassed auto
QF_MeatFarmCagedMeatslaves_04004C91 property CageHandler auto
MeatFarmCattleMenu property CattleMenu auto
MeatFarmTroughScript property Trough auto
MeatFarmSkipHandler property Skipper auto
MeatFarmMCM property MCM auto

;Quests
Quest  property EvalQuest_NPC auto
Quest  property EvalQuest_Player auto
Quest property Mate1 auto
Quest property RichBuyer auto
Quest property Hungry auto
Quest property Flu auto
Quest property TalosDay auto
Quest property Breeding auto
Quest property CutCosts auto
Quest property ForgotToFeed auto
Quest property RestockAlt auto

;Variables
Bool ReadyForDailyEvent = true
Int CurrentDaysPassed

Event OnInit() 
	;Note: for quests, OnInit is called once at game startup and again whenever the quest starts
	;Hence why the scheduler was giving Daily Event Messages BEFORE the player became a cattle

	CurrentDaysPassed= GameDaysPassed.GetValue() as Int

	if Self.IsRunning() || self.IsStarting()
		RegisterForUpdate(5.0)
	endIf
endEvent

event OnUpdate()

	;Check if a new day
	if GameDaysPassed.GetValue() as Int > CurrentDaysPassed
		CurrentDaysPassed = GameDaysPassed.GetValue() as Int
		CattleMenu.DaysAsCattle += 1
		ReadyForDailyEvent = true
		Trough.IsNotFull = true ;make it so player can eat from trough again
		Trough.TimesEatenToday = 0
	endIf
	
	;Check if time for an evaluation quest
	float time = GameHour.GetValue() as Float
	if ( time > 8.1667) && (time < 18 ) && ReadyForDailyEvent && self.IsRunning() ;Eval time is between 8:10 am - 6:00 pm
		int debugID = DailyEvent()
		if MCM.DADebugCodes
			debug.messagebox(debugID)
		endIf
		ReadyForDailyEvent = false
	endIf
endEvent

int Function DailyEvent()
	;if today is the first day, don't do anything
	;or if certain quests are already active (ex: breeding quest)
	if CattleMenu.DaysAsCattle == 0 || Breeding.IsRunning()
		return 1
	endIf

	;Otherwise, choose a daily event, but first disable skipping
	Skipper.CanSkipNow = False

	float rand
	rand = Utility.RandomFloat() 

	;player eval
	if (CattleMenu.DaysAsCattle % 7 == 0)
		EvalQuest_Player.Start()
		debug.notification("You think today might be your day")
		return 2

	;Talos Day
	elseif CattleMenu.DaysAsCattle == 13
		TalosDay.Start()
		return 3

	;Breeding quest (20% chance if marbling is close to ideal)
	elseif CattleMenu.Marbling > 40 && CattleMenu.Marbling < 60 && Utility.RandomFloat() < 0.2
		Breeding.Start()
		return 4

	;Restock
	elseif CageHandler.KilledCattle >= 3
		if rand < 0.7 ;default restock (70% chance)
			CageHandler.Restock()
			SendModEvent("MeatFarm_EnableSkip") ;since the default restock isn't a quest, we'll put this here instead
			return 5
		else ;alternative restock (30% chance)
			RestockAlt.Start()
			return 6
		endIf

	;Hungry (20% chance)
	elseIf rand < 0.20 
		Hungry.Start()
		return 7

	;Flu (7% chance)
	elseIf rand < 0.27
		Flu.Start()
		return 8

	;RichBuyer (8% chance)
	elseIf rand < 0.35 
		RichBuyer.Start()
		return 9

	;CutCosts (8% chance)
	elseIf rand < 0.43 
		CutCosts.Start()
		return 10

	;ForgotToFeed (11% chance)
	elseIf rand < 0.54 
		ForgotToFeed.Start()
		return 11

	;Mate questline (15% chance)
	elseIf rand < 0.69 && !(Mate1.IsRunning() )
		Mate1.Start()
		return 12

	;NPC eval (31-46% chance)
	else
		EvalQuest_NPC.Start()
		return 13
	endIf

endFunction


Function ForceStartNewDay()
	CurrentDaysPassed = 0
	;this will force the system to think a new day has come on the next update
endFunction